@@ -87,7 +87,7 @@ main(int argc, char **argv) {
   unsigned char *data_dir_string;
   unsigned char *query_string;
   int count = 0;
-#if RASQAL_DEBUG > 1
+#if defined(RASQAL_DEBUG) && RASQAL_DEBUG > 1
   raptor_serializer* serializer=NULL;
 #endif
 
@@ -110,8 +110,11 @@ main(int argc, char **argv) {
 
   data_dir_string = raptor_uri_filename_to_uri_string(argv[1]);
 
-  query_string = (unsigned char*)RASQAL_MALLOC(cstring, strlen((const char*)data_dir_string)+strlen(data_file)+strlen(query_format)+1);
+  query_string = RASQAL_MALLOC(unsigned char*, strlen((const char*)data_dir_string) + strlen(data_file) + strlen(query_format) + 1);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
   sprintf((char*)query_string, query_format, data_dir_string, data_file);
+#pragma GCC diagnostic pop
   raptor_free_memory(data_dir_string);
 
   query = rasqal_new_query(world, query_language_name, NULL);
@@ -130,7 +133,7 @@ main(int argc, char **argv) {
     goto done;
   }
   
-  RASQAL_FREE(cstring, query_string);
+  RASQAL_FREE(char*, query_string);
   
   printf("%s: executing query\n", program);
   results = rasqal_query_execute(query);
@@ -147,7 +150,7 @@ main(int argc, char **argv) {
     goto done;
   }
 
-#if RASQAL_DEBUG > 1
+#if defined(RASQAL_DEBUG) && RASQAL_DEBUG > 1
   serializer = raptor_new_serializer("ntriples");
   raptor_serialize_start_to_file_handle(serializer, base_uri, stdout);
 #endif
@@ -159,14 +162,14 @@ main(int argc, char **argv) {
       break;
     count++;
     
-#if RASQAL_DEBUG > 1
+#if defined(RASQAL_DEBUG) && RASQAL_DEBUG > 1
     raptor_serialize_statement(serializer, triple);
 #endif
     if(rasqal_query_results_next_triple(results))
       break;
   }
   
-#if RASQAL_DEBUG > 1
+#if defined(RASQAL_DEBUG) && RASQAL_DEBUG > 1
   raptor_serialize_end(serializer);
   raptor_free_serializer(serializer);
 #endif
